@@ -9,6 +9,8 @@ pub mod vocab;
 pub mod batching;
 /// Dataloader module contains the main dataloader struct, as well as dataloader utilities
 pub mod dataloader;
+/// Pipeline module contains the dataflow pipeline struct, as well as all pipeline utilities
+pub mod pipeline;
 
 extern crate log;
 #[macro_use]
