@@ -1,5 +1,7 @@
 use super::Tokenizer;
+use serde::{Deserialize, Serialize};
 
+#[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct AlphabetTokenizer {}
 
 impl Tokenizer for AlphabetTokenizer {
@@ -12,7 +14,7 @@ impl Tokenizer for AlphabetTokenizer {
         tokens[1..tokens.len()-1].to_vec() // For some reason, the split adds empty strings to each end
     }
 
-    fn batch_tokenize(&self, strings: Vec<&str>) -> Vec<Vec<String>> {
+    fn batch_tokenize(&self, strings: Vec<String>) -> Vec<Vec<String>> {
         strings.iter().map(|string| {
             string.split("").map(|f| {f.to_string()}).collect()
         }).collect()
