@@ -55,11 +55,11 @@ impl Tokenizer for WordpieceTokenizer {
     }
 
     fn untokenize(&self, tokens: Vec<String>) -> String {
-        let punctuation: Vec<String>  = [".", "?", "!", ",", "'", r#"""#].iter().map(|a|{a.to_string()}).collect();
+        
         let mut untokenized_string = String::new();
         for (i, token) in tokens.iter().enumerate() {
             if *token != "[PAD]" && *token != "[EOS]" {
-                if token.contains("##") || punctuation.contains(&token) || i == 0 {
+                if token.contains("##") || [".", "?", "!", ",", "'", r#"""#].iter().any(|x| *x == token) || i == 0 {
                     untokenized_string = format!("{}{}", untokenized_string, token.replace("##", ""))
                 }else {
                     untokenized_string = format!("{} {}", untokenized_string, token)
@@ -70,12 +70,12 @@ impl Tokenizer for WordpieceTokenizer {
     }
 
     fn batch_untokenize(&self, tokens: Vec<Vec<String>>) -> Vec<String> {
-        let punctuation: Vec<String>  = [".", "?", "!", ",", "'", r#"""#].iter().map(|a|{a.to_string()}).collect();
+        
         let mut untokenized_strings = vec![String::new(); tokens.len()];
         for i in 0..tokens.len() {
             for x in 0..tokens[i].len() {
                 if *tokens[i][x] != *"[PAD]" && *tokens[i][x] != *"[EOS]" {
-                    if tokens[i][x].contains("##") || punctuation.contains(&tokens[i][x]) || x == 0 {
+                    if tokens[i][x].contains("##") || [".", "?", "!", ",", "'", r#"""#].iter().any(|t| **t == tokens[i][x]) || x == 0 {
                         untokenized_strings[i] = format!("{}{}", untokenized_strings[i], tokens[i][x].replace("##", ""))
                     }else {
                         untokenized_strings[i] = format!("{} {}", untokenized_strings[i], tokens[i][x])
